
.. If you created a package, create one automodule per module in the package.

.. automodule:: adafruit_bme280
   :members:

.. automodule:: adafruit_bme280.basic
   :members:

.. automodule:: adafruit_bme280.advanced
   :members:
